<?php
namespace CMP\Util;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class Util {
	
	const PARAMGERAL = 'paramgeral';
	const PARAMFILIAL = 'paramfilial';

	protected $environment;
	protected $dataSourceManager;

	public function __construct($environment, $dataSourceManager) {
		$this->environment = $environment;
		$this->dataSourceManager = $dataSourceManager;
	}

	public function retornaDataProcessamento() {

		$dataSet = $this->dataSourceManager->findBy(new FilterCriteria(self::PARAMGERAL));

		$rows = $dataSet->getRows();

		if ($rows[0]['IDUTILDTPROC'] != 'S') {

			$dataProcessamento = date('d/m/Y');

		} else {
			
			$dataProcessamento = $this->retornaDataProcPorFilial($this->environment->getCdFilial());

		}

		return $this->truncDate($dataProcessamento);

    }

    public function retornaDataProcPorFilial($cdfilial) {

		$filterCriteria = new FilterCriteria(self::PARAMFILIAL);
		$filterCriteria->addCondition('CDFILIAL', $cdfilial);
		$dataSet = $this->dataSourceManager->findBy($filterCriteria);
		$rows = $dataSet->getRows();

		if (!empty($rows) && !empty($rows[0])) {
            $dataProcessamento = $rows[0]['DTPROCESSA'];
		}
        else{
            $dataProcessamento = date('d/m/Y');
        }

		return $this->truncDate($dataProcessamento);

    }

    private function truncDate($date) {
    	$date = explode(' ', $date);
    	return $date[0];
    }

    public function validateUserGroup(DTO\Request $request, DTO\Response $response) {

    	$row = $request->getRow();

    	$permission = array('isValid' => $this->permissaoOperadorPorGrupo($row));

    	$response->addDataSet(new DataSet('permission', $permission));
    }    

    public function permissaoOperadorPorGrupo($row) {

        $filterCriteria = new FilterCriteria('opergrupop');
        $filterCriteria->addCondition('CDOPERADOR', $row['cdoperador']);
        $filterCriteria->addCondition('CDGRUPOPER', $this->retornaGrupoDeOperador($row['idgrupoper']));
        $filterCriteria->addCondition('NRORG', $this->environment->getNrOrgTrab());

        $dataSet = $this->dataSourceManager->findBy($filterCriteria);
        $rows = $dataSet->getRows();

        return isset($rows[0]) ? true : false;
    }

    public function retornaGrupoDeOperador($idautgrupop) {

        $filterCriteria = new FilterCriteria('autgrupop');
        $filterCriteria->addCondition('IDAUTGRUPOP', $idautgrupop);
        $filterCriteria->addCondition('NRORG', $this->environment->getNrOrgTrab());

        $dataSet = $this->dataSourceManager->findBy($filterCriteria);
        $rows = $dataSet->getRows();

        return isset($rows[0]) ? $rows[0]['CDGRUPOPER'] : null;

    }

    public function retornaCentralDefault() {

        $filterCriteria = new FilterCriteria('filial');
        $filterCriteria->addCondition('CDFILIAL', $this->environment->getCdFilial());
        $filterCriteria->addCondition('NRORG', $this->environment->getNrOrgTrab());
       
        $dataSetLogged = $this->dataSourceManager->findBy($filterCriteria);
        $rowsLogged = $dataSetLogged->getRows();
        if($rowsLogged[0]['CDFILCENTPME']) {
            $filterCriteria = new FilterCriteria('filial');
            $filterCriteria->addCondition('CDFILIAL', $rowsLogged[0]['CDFILCENTPME']);
            $filterCriteria->addCondition('NRORG', $this->environment->getNrOrgTrab());

            $dataSet = $this->dataSourceManager->findBy($filterCriteria);
            $rows = $dataSet->getRows();         
        } else {
            $filterCriteria = new FilterCriteria('filial');
            $filterCriteria->addCondition('CDFILCENTPME', $this->environment->getCdFilial());
            $filterCriteria->addCondition('NRORG', $this->environment->getNrOrgTrab());

            $dataSet = $this->dataSourceManager->findBy($filterCriteria);
            $rows = $dataSet->getRows();
            if(isset($rows[0])) {
                $rows = $rowsLogged;
            }
        }

        return isset($rows[0]) ? $rows[0] : $rows;

    }
}