<?php
namespace Teknisa\CMP\Modules\Fornecimento\Modules\AutorizacaoFornecimento\Controllers; 

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\CMP\Util\CmpUtilities;
use Zeedhi\Framework\ORM\DateTime;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\CMP\Util\Attachment;

class Cmp07600AlteracaoAprovacaoAfController extends \Teknisa\GER\Controllers\TeknisaCrud {
    
    protected $alteracaoAprovacaoAfService;
    protected $cmpUtilities;
    protected $fechamentoAF;
    protected $stNomeRel;
    protected $reportController;
    protected $globalReports = [];
    
    public function __construct ($crudService, $parameterBag, $alteracaoAprovacaoAfService, CmpUtilities $cmpUtilities, $fechamentoAF, $reportController) {
        
        $this->alteracaoAprovacaoAfService  = $alteracaoAprovacaoAfService;
        $this->cmpUtilities                 = $cmpUtilities;
        $this->fechamentoAF                 = $fechamentoAF;
        $this->reportController             = $reportController;
        
        parent::__construct($crudService, $parameterBag);
    }
    
    public function parseFloat($floatVar) {
        if(is_string($floatVar)) {
            $floatVar = str_replace(".", "", $floatVar);    
            $floatVar = str_replace(",", ".", $floatVar);
        }
        return $floatVar;
    }
    
    public function getSystemParamGeral(DTO\Request $row, DTO\Response $response){
        
        $paramGeral = $this->alteracaoAprovacaoAfService->getSystemParamGeral();
        $response->addDataSet(new DataSet("PARAMGERAL", $paramGeral));
        
    }
    
    public function getAfInfos(DTO\Request $row, DTO\Response $response){
        
        $row = $row->getRow();
        $infos = array();
        
        $branchOperator = self::getBranchOperator($row);
        $infos["BRANCH_OPERATOR"] = $branchOperator;
        
        $row["CDFILCENTCMP"] = self::getTradingCenter($row);
        $infos["TRADING_CENTER"] = $row["CDFILCENTCMP"];
        
        $permissions = self::getPermissions($row);
        $infos["PERMISSIONS"] = $permissions;
        
        $integration = self::getIntegration($row);
        $infos["INTEGRATION"] = $integration;
        
        $frequency = self::getFrequency($row);
        $infos["FREQUENCY"] = $frequency;
        
        $response->addDataSet(new DataSet("AF_INFOS", array($infos)));
        
    }
    
    public function getBranchOperator($row){
        
        $selectParams = array(
            "P_CDFILDEST" => $row["CDFILDEST"]
        );
        
        $operators = $this->alteracaoAprovacaoAfService->getBranchOperator($selectParams);
        return $operators;
        
    }
    
    public function getTradingCenter($row) {
        $selectParams = array(
            "P_CDFILDEST" => $row["CDFILDEST"]
        );
        
        $tradingCenter = $this->alteracaoAprovacaoAfService->getTradingCenter($selectParams);
        
        return $tradingCenter[0]["CDFILCENTCMP"];
    }
    
    public function getPermissions($row){
        $selectParams = array(
            "P_CDFILCENTCMP" => $row["CDFILCENTCMP"]
        );
        $permissions = $this->alteracaoAprovacaoAfService->getPermissions($selectParams);
        return $permissions;
        
    }
    
    public function getIntegration($row){
        
        $selectParams = array(
            "P_CDFILDEST"   => $row["CDFILDEST"],
            "P_NRAUTOFORN"  => $row["NRAUTOFORN"]
        );
        
        $integration = $this->alteracaoAprovacaoAfService->getIntegration($row, $selectParams);
        return $integration;
        
    }
    
    public function getFrequency($row){
        
        $selectParams = array(
            "P_CDFILDEST"     => $row["CDFILDEST"],
            "P_CDFORNECED"  => $row["CDFORNECED"]
        );
        
        $frequency = $this->alteracaoAprovacaoAfService->getFrequency($selectParams);
        return $frequency;
        
    }
    
    public function executeProcedureCarregaPeriforn(DTO\Request $request, DTO\Response $response){
      
        $row = $request->getRow();
        $returnedDate = $this->alteracaoAprovacaoAfService->executeProcedureCarregaPeriforn($row);
        
        $response->addDataSet(new DataSet("DATA", array("RETURNED_DATE" => $returnedDate)));
        
    }
    
    public function sendEmailToProductResponsibleOperators(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $responsilbleOperators = self::getAfResponsibleOperators($row);
        
        if (empty($responsilbleOperators)) {
            $msg = 'Impossível enviar e-mail, não há operador responsável por esta unidade.';
            $response->setError(new Error($msg, 1));
        }
        
        $row["OPERADORES_RESPONSAVEIS"] = $responsilbleOperators;
        
        $this->alteracaoAprovacaoAfService->sendEmailToProductResponsibleOperators($row);
        
    }
    
    public function getAfResponsibleOperators($row){
        
        $selectParams = array(
            "P_CDFILDEST"     => $row["CDFILDEST"]
        );
        
        $operators = $this->alteracaoAprovacaoAfService->getAfResponsibleOperators($selectParams);
        return $operators;
        
    }
    
    public function updateAllAfProductDeliveryDate(DTO\Request $request, DTO\Response $response){
        
        $row = $request->getRow();
        
        $updateParams = array(
            
            "P_CDFILDEST"   => $row["CDFILDEST"],
            "P_CDFILLANC"   => $row["CDFILLANC"],
            "P_NRAUTOFORN"  => $row["NRAUTOFORN"],
            "P_DTNOVAENTRAF"  => $row["DTNOVAENTRAF"]
            
        );
        
        $this->alteracaoAprovacaoAfService->updateAllAfProductDeliveryDate($updateParams);
        
    }
    
    public function getProductsWithNewDeliveryDate(DTO\Request $request, DTO\Response $response){
        
        $row = $request->getRow();
        
        $selectParams = array(
            
            "P_CDFILDEST"   => $row["CDFILDEST"],
            "P_CDFILLANC"   => $row["CDFILLANC"],
            "P_NRAUTOFORN"  => $row["NRAUTOFORN"]
            
        );
        
        $products = $this->alteracaoAprovacaoAfService->getProductsWithNewDeliveryDate($selectParams);
        $response->addDataSet(new DataSet("PRODUCTS", $products));
    }
    
    public function updateInconsistencyAF(DTO\Request $request, DTO\Response $response) {
        $limiteParam   = $request->getRow()[0];
        $inconsisParam = $request->getRow()[1];
        $dadosAF       = $request->getRow()[2];
            
        try {
            $parcmpsup     = $this->alteracaoAprovacaoAfService->getParcmpsup(["CDFILIAL" => $dadosAF["CDFILDEST"], "NRORG" => $dadosAF["NRORG"]])[0];
            
            if(sizeof($limiteParam) > 0) {
                $dadosAF["IDAFFORALIM"] = "S";
                $dadosAF["CDGERENTE"]   = ", CDGERENTE = ''";
            } else {
                $dadosAF["IDAFFORALIM"] = "N";
                $dadosAF["CDGERENTE"]   = "";
            }
            
            if(sizeof($inconsisParam) > 0 || $parcmpsup["IDOBLIBAFMAN"] == "S") {
                $dadosAF["IDSITUATUAAF"] = "1";
            } else {
                $dadosAF["IDSITUATUAAF"] = "";
            }
            
            // Salva AF
            $this->alteracaoAprovacaoAfService->updateAf($dadosAF);
            
            // Atualiza Contar a Pagar
            $tpctpagar  = $this->alteracaoAprovacaoAfService->updateCdtpctpagar($dadosAF);
            
            // Procedure CUSTO_AF
            $dadosAF["NRSEQAPURAF"] = null;
            $this->alteracaoAprovacaoAfService->CUSTO_AF($dadosAF);
            
            $response->addMessage(new Message("Success"));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function insertTaxes(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            $autoforne = $taxes = $this->getAutoforne($row);
            $row['CDEMPRESA'] = $autoforne[0]['CDEMPRESA'];
            
            $taxes = $this->checkTaxes($row);
            
            if(sizeof($taxes) > 0) {
                $row["CDINSCESTA"] = $taxes[0]["CDINSCESTA"];
                $this->alteracaoAprovacaoAfService->IMPOSTO_ITEMAF($row);
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function getCentralCompras(DTO\Request $request, DTO\Response $response){
        
        $row = $request->getRow();
        
        $centralDeCompras = $this->cmpUtilities->getCentralCompras();
        
        $response->addDataSet(new DataSet("res", $centralDeCompras));
    }
    
    public function checkTaxes($params) {
        $conditions = array(
            ["columnName" => "CDFILDEST",   "operator" => "=",    "value" => $params["CDFILDEST"]],
            ["columnName" => "CDEMPRESA",   "operator" => "=",    "value" => $params["CDEMPRESA"]],
            ["columnName" => "NRORG",       "operator" => "=",    "value" => $params["NRORG"]    ]
        );
        $taxes = $this->crudService->getFilteredDataSet("cmp03900_verificaImposto", $conditions)->getRows();
        return $taxes;
    }
    
    public function getAutoforne($params) {
        $conditions = array(
            ["columnName" => "CDFILDEST",   "operator" => "=",    "value" => $params["CDFILDEST"]],
            ["columnName" => "CDFILLANC",   "operator" => "=",    "value" => $params["CDFILLANC"]],
            ["columnName" => "NRAUTOFORN",  "operator" => "=",    "value" => $params["NRAUTOFORN"]],
            ["columnName" => "NRORG",       "operator" => "=",    "value" => $params["NRORG"]]
        );
        
        $autoforne = $this->crudService->getFilteredDataSet("autoforne", $conditions)->getRows();
        return $autoforne;
    }
    
    public function getParamSupplier(DTO\Request $request, DTO\Response $response){
        
        $row = $request->getRow();
        
        $params = array(
            
            "P_CDFILDEST"   => $row["CDFILDEST"],
            "P_NRAUTOFORN"   => $row["NRAUTOFORN"]
            
        );
        
        $paramsSupplier = $this->alteracaoAprovacaoAfService->getParamSupplier($params);
        $response->addDataSet(new DataSet("PARAM", $paramsSupplier));
    }
    
    public function approvalItemAf(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $getRow = $request->getRow();
            $rows = $getRow['ROWS'];
            $boAtuali = $getRow['ATUSOLI'];
            $enviaEmailGestor = $getRow['EMAIL_GESTOR_AF'];
            $enviaEmailForn = $getRow['EMAIL_FORN_AF'];
            $nmOperador = $getRow['NMOPERADOR'];
            
            foreach($rows as $row) {
                $stIdOperacao = null;
                $msgJust = $row['JUSTIFICATIVA'];
                $tipo = $row['NMSITITEM'];
                    
                if($row['QTNOVAPROGAF'] != null && $row['DTNOVAENTRAF'] != null) {
                    if(self::parseFloat($row['QTNOVAPROGAF']) == 0) {
                        $stIdOperacao = 'E';
                    } else {
                        $stIdOperacao = 'A';
                    }
                } else if($row['DTNOVAENTRAF'] != null) {
                    $stIdOperacao = 'A';
                } else if($row['QTNOVAPROGAF'] != null) {
                    if(self::parseFloat($row['QTNOVAPROGAF']) == 0) {
                        $stIdOperacao = 'E';
                    } else {
                        $stIdOperacao = 'A';
                    }
                }
                if($boAtuali && $tipo == 'A') {
                    if($row['QTNOVAPROGAF'] != null && $row['QTNOVAPROGAF'] != $row['QTORIG']) {
                        (float)$dbQtSoliProd = self::parseFloat($row['QTNOVAPROGAF']) - self::parseFloat($row['QTORIG']);
                            
                        $adqEntrItmSol = $this->alteracaoAprovacaoAfService->adqEntrItmSol($row);
                            
                        $adqItemSoli = $this->alteracaoAprovacaoAfService->adqItemSoli($row, $adqEntrItmSol);
                            
                        if(count($adqItemSoli) > 0) {
                            foreach($adqItemSoli as $itmSol) {
                                (float)$dbQtSoliProd = $dbQtSoliProd * self::parseFloat($itmSol['VRFATOCONV']) / self::parseFloat($itmSol['VRFATOSOLI']);
                                    
                                if($dbQtSoliProd > 0) {
                                    $this->alteracaoAprovacaoAfService->acmUpQtSoliProd($itmSol, $dbQtSoliProd);
                                    $this->alteracaoAprovacaoAfService->acmInsMovOpSol($itmSol, $msgJust, (self::parseFloat($itmSol['QTSOLIPROD']) + $dbQtSoliProd));
                                        
                                    $dbQtSoliProd = 0;
                                }
                                if($dbQtSoliProd < 0) {
                                    if(self::parseFloat($itmSol['QTSOLIPROD']) > $dbQtSoliProd) {
                                        $this->alteracaoAprovacaoAfService->acmUpQtSoliProd($itmSol, $dbQtSoliProd);
                                        $this->alteracaoAprovacaoAfService->acmInsMovOpSol($itmSol, $msgJust, (self::parseFloat($itmSol['QTSOLIPROD']) + $dbQtSoliProd));
                                            
                                        $dbQtSoliProd = 0;
                                    } else {
                                        $this->alteracaoAprovacaoAfService->acmDelItemSoli($itmSol);
                                        $this->alteracaoAprovacaoAfService->acmInsMovOpSol($itmSol, $msgJust, 0);
                                            
                                        (float)$dbQtSoliProd = $dbQtSoliProd + self::parseFloat($itmSol['QTSOLIPROD']);
                                    }
                                }
                            }
                        }
                    }
                }
                if($row['DTNOVAENTRAF'] != null) {
                    if(substr($row['DTNOVAENTRAF'], 0, 10) != substr($row['DTPROGENTAF'], 0, 10)) {
                        $adqAux_Imposto = $this->alteracaoAprovacaoAfService->adqAux_Imposto($row);
                            
                        if(count($adqAux_Imposto) > 0) {
                            if(self::parseFloat($adqAux_Imposto[0]['CTIMP']) > 0) {
                                $this->alteracaoAprovacaoAfService->acmDelImpItm($row);
                                    
                                if($stIdOperacao != 'E') {
                                    $adqExisteItemautf = $this->alteracaoAprovacaoAfService->adqExisteItemautf($row);
                                        
                                    $this->alteracaoAprovacaoAfService->acmDelItemSoliRelacAF($row);
                                        
                                    if(count($adqExisteItemautf) == 0) {
                                        $this->alteracaoAprovacaoAfService->acmUpdItm($row, $tipo, $msgJust, null);
                                    } else {
                                        $this->alteracaoAprovacaoAfService->acmUpdItm($row, $tipo, $msgJust, $adqExisteItemautf);
                                        
                                        $this->alteracaoAprovacaoAfService->acmDelItemAutF($row);
                                    }
                                }
                                
                                foreach($adqAux_Imposto as $imp) {
                                    $this->alteracaoAprovacaoAfService->acmInsImpItm($row, $imp);
                                }
                            } else {
                                if($stIdOperacao != 'E') {
                                    $adqExisteItemautf = $this->alteracaoAprovacaoAfService->adqExisteItemautf($row);
                                        
                                    $this->alteracaoAprovacaoAfService->acmDelItemSoliRelacAF($row);
                                        
                                    if(count($adqExisteItemautf) == 0) {
                                        $this->alteracaoAprovacaoAfService->acmUpdItm($row, $tipo, $msgJust, null);
                                    } else {
                                        $this->alteracaoAprovacaoAfService->acmUpdItm($row, $tipo, $msgJust, $adqExisteItemautf);
                                        
                                        $this->alteracaoAprovacaoAfService->acmDelItemAutF($row);
                                    }
                                }
                            }
                        } else {
                            if($stIdOperacao != 'E') {
                                $adqExisteItemautf = $this->alteracaoAprovacaoAfService->adqExisteItemautf($row);
                                        
                                $this->alteracaoAprovacaoAfService->acmDelItemSoliRelacAF($row);
                                        
                                if(count($adqExisteItemautf) == 0) {
                                    $this->alteracaoAprovacaoAfService->acmUpdItm($row, $tipo, $msgJust, null);
                                } else {
                                    $this->alteracaoAprovacaoAfService->acmUpdItm($row, $tipo, $msgJust, $adqExisteItemautf);
                                        
                                    $this->alteracaoAprovacaoAfService->acmDelItemAutF($row);
                                }
                            }
                        }
                    } else {
                        $this->alteracaoAprovacaoAfService->acmUpdItm($row, $tipo, $msgJust, null);
                    }
                } else {
                    $this->alteracaoAprovacaoAfService->acmUpdItm($row, $tipo, $msgJust, null);
                }
                if($row['QTNOVAPROGAF'] != null) {
                    if(self::parseFloat($row['QTNOVAPROGAF']) != self::parseFloat($row['QTORIG'])) {
                        $this->fechamentoAF->fechaAF($row['CDFILDEST'], $row['CDFILLANC'], $row['NRAUTOFORN'], self::getTradingCenter($row));
                    }
                }
                if($row['QTNOVAPROGAF'] != null && self::parseFloat($row['QTNOVAPROGAF']) == 0) {
                    $this->alteracaoAprovacaoAfService->acmDelItemAutF($row);
                }
                if($tipo == 'R') {
                    if($row['QTNOVAPROGAF'] != null && self::parseFloat($row['QTNOVAPROGAF']) == 0) {
                        $this->alteracaoAprovacaoAfService->acmDelItemAutF($row);
                    }
                    $sqlWT = $this->alteracaoAprovacaoAfService->sqlWebTunning();
                    
                    $this->alteracaoAprovacaoAfService->acmInsMovOpAF($row, $sqlWT[0], $msgJust, $stIdOperacao);
                    $this->alteracaoAprovacaoAfService->acmInsLogPlanItemAF($row, $msgJust, $stIdOperacao);
                }
                if($msgJust != null || $msgJust != '' || !empty($msgJust)) {
                    $sqlWT = $this->alteracaoAprovacaoAfService->sqlWebTunning();
                    
                    $this->alteracaoAprovacaoAfService->acmInsMovOpAF1($row, $sqlWT[0], $msgJust, $stIdOperacao);
                    $this->alteracaoAprovacaoAfService->acmInsLogPlanItemAF1($row, $msgJust, $stIdOperacao);
                }
            }
            
            $verifCtPag = $this->alteracaoAprovacaoAfService->adqVerifCtPag($rows[0])[0];
            
            if($verifCtPag <= 1) {
                $this->alteracaoAprovacaoAfService->acmUpdateTpCtPagar($rows[0]);    
            }else{
                $this->alteracaoAprovacaoAfService->acmUpdateTpCtPagar1($rows[0]);          
            }
            $this->alteracaoAprovacaoAfService->fechamento_af($rows[0]);
            $this->alteracaoAprovacaoAfService->exclui_contapagar_prevista($rows[0]);
            $this->alteracaoAprovacaoAfService->gera_contapagar_prevista($rows[0]);
            $haveAF = array();
            $haveAF[] = $this->alteracaoAprovacaoAfService->retornaAF($rows[0])[0];
            
            if($haveAF[0]['NRSEQENVIOAFORN'] == null) {
                if($haveAF[0]['IDTPENVAFNORMAL'] == 'P') {
                    $stNrEnvio = $this->alteracaoAprovacaoAfService->procedureGeraNovoCodigo('ENVIOAFFORN');
                    
                    $adqDadosEmail = $this->alteracaoAprovacaoAfService->adqDadosEmail($haveAF[0], self::getTradingCenter($haveAF[0]));
                    
                    $dtEntrega = null;
                    
                    if(count($adqDadosEmail) > 0) {
                        $adqDtEntregaAf = $this->alteracaoAprovacaoAfService->adqDtEntregAF($adqDadosEmail[0]);
                        
                        $dtEntrega = isset($adqDtEntregaAf) ? count($adqDtEntregaAf) > 0 ? $adqDtEntregaAf[0]['DTPROGENTAF'] : null : null;
                        
                        $this->alteracaoAprovacaoAfService->acmInsEnviaAF($adqDadosEmail[0], $haveAF[0], $stNrEnvio, $dtEntrega);
                    
                        foreach($adqDadosEmail as $dado) {
                            $this->alteracaoAprovacaoAfService->acmUpdAutoForne($dado, $stNrEnvio);
                            
                            $adqDtEntregaAf = $this->alteracaoAprovacaoAfService->adqDtEntregAF($dado);
                            
                            $dtEntrega = isset($adqDtEntregaAf) ? count($adqDtEntregaAf) > 0 ? $adqDtEntregaAf[0]['DTPROGENTAF'] : null : null;
                        }
                        
                        $adqDadosRemaneja = $this->alteracaoAprovacaoAfService->adqDadosRemaneja($adqDadosEmail[0]);
                        
                        if(count($adqDadosRemaneja) > 0) {
                            $confirmaEnvio = 'N';
                            
                            $this->alteracaoAprovacaoAfService->acmUpdEnviaAF($haveAF[0], $adqDadosEmail[0], $confirmaEnvio);
                        }
                    }
                }
            } else {
                $this->alteracaoAprovacaoAfService->acmUpdAutoForne1($rows[0]);
            }
            
            $adqEmailAprov = $this->alteracaoAprovacaoAfService->adqEmailAprov($rows[0]);
            
            self::enviaEmailDeAprovacao($adqEmailAprov, $rows);
            
            $params = array(
                'QR2TYPE'       => 'PDF',
                'STRATEGY'      => 'BIRT',
                'CDFILIAL'      => $rows[0]['CDFILDEST'],
                'NRAUTOFORN'    => $rows[0]['NRAUTOFORN'],
                'CDFILLANC'     => $rows[0]['CDFILLANC'],
                'NRORG'         => $rows[0]['NRORG']
            );
            
            $this->globalReports[] = $this->reportController->returnAFReport($params);
            
            if($enviaEmailGestor == true) {
                $adqEmailGestorAF = $this->alteracaoAprovacaoAfService->adqEmailGestorAF($rows[0])[0];
                
                $getAF = $this->alteracaoAprovacaoAfService->retornaAF($rows[0])[0];
                
                self::enviaEmailGestor($adqEmailGestorAF, $getAF);
            }
            
            if($enviaEmailForn == true) {
                $getAF = $this->alteracaoAprovacaoAfService->retornaAF($rows[0])[0];
                $listaEmailFornecedor = $this->alteracaoAprovacaoAfService->adqEmailFornecedor($getAF)[0];
                
                $assunto = 'Autorização de Fornecimento';
                $message = "Prezado Fornecedor, <i>__NMFANTFORN__</i><br/><br/>Parabéns! Você foi selecionado em nosso processo de cotação.<br/>A Autorização de Fornecimento foi disponibilizada em nosso Portal de Compras.<br/><br/>Acesse <i>__PARAMPORTAL__</i> e confira no Número de Lote <i>__NRSEQAPURAF__</i> das AFs disponíveis.<br/><br/>Lembramos que não são permitidas entregas em desacordo com a Autorização de Fornecimento. Sendo o fornecedor responsável por divergências ou possíveis devoluções.<br/><br/>Verifique atentamente o local de entrega, dados de faturamento de cada unidade, produtos, marcas, preços, embalagens, quantidades e demais informações.<br/><br/>Siga rigorosamente a Autorização de Fornecimento!<br/><br/>Att<br/>". $nmOperador ."<br/>";
                
                if($listaEmailFornecedor) {
                    if($listaEmailFornecedor['IDTPENVAFFOR'] !== '1') {
                        //MAIL_NOT_SENDED_IDTPENVAFFOR
                    } else {
                        $enderecos = explode(";", $listaEmailFornecedor['DSEMAILCOT']);
                        if(empty($enderecos[0])) {
                            //EMAIL_N_REGISTERED
                        } else {
                            if($listaEmailFornecedor['IDTPENVAFNORMAL'] === 'E') {
                                
                            }
                            
                            $isEmailSend = self::sendEmailForn($rows[0], $assunto, $message, $listaEmailFornecedor, $enderecos);
                        }
                    }
                }
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    private function sendEmailForn($row, $assunto, $message, $listaEmailFornecedor, $enderecos, $reportName = null) {
        //$this->cookieUtil->setCookie($row, $dadosEmail);
        
        $result = self::tratarMensagemCorpoEmailForn($row, $assunto, $message, $reportName, $listaEmailFornecedor);
        
        $message          = $result[0];
        $attachments      = $result[1];
        $clearAttachments = $result[2];
        
        $messageSendMail = $this->cmpUtilities->messageSendMail(null, $assunto, $message, 'TECFOOD');
        $enderecosCopia = !empty($listaEmailFornecedor["DSMAILCOTCOP"]) ? explode(";", $listaEmailFornecedor["DSMAILCOTCOP"]) : false;
        
        //if($dadosEmail['SENDOPERATOR'] === 'S') {
        //    $enderecosCopia[] = $this->service->getCurrentEmail();
        //}
        
        if(empty($enderecos[0])) {
            //EMAIL_N_REGISTERED
        } else {
            try{
                return $this->cmpUtilities->enviaEmail('', $assunto, $enderecos, $messageSendMail, $enderecos, $enderecos, $attachments, $clearAttachments);
            } catch (\Exception $e) {
                return false;
            }
        }
    }
    
    private function tratarMensagemCorpoEmailForn($row, $assunto, $message, $reportName, $listaEmailFornecedor) {
        $dataset = $this->alteracaoAprovacaoAfService->retornaLinkEcommerce(self::getTradingCenter($row));
        
        $encontrar  = array("<i>__NMFANTFORN__</i>", "<i>__PARAMPORTAL__</i>", "<i>__NRSEQAPURAF__</i>");
        $substituir = array($listaEmailFornecedor['NMFANTFORN'], $dataset['DSLINKECOMMERCE'], $row['NRSEQAPURAF']);
        
        $message    = str_replace($encontrar, $substituir, $message);
        
        $attachments = [];
        $attOnBody = '';
        $clearAttachments = true;
        
        if($listaEmailFornecedor['IDTPENVAFNORMAL'] === 'E') {
            foreach ($this->globalReports as $name => $report) {
                $fileName = ($reportName ? $reportName : $row["NRAUTOFORN"]) . '.' . strtolower('PDF');
                
                $attachment = new Attachment($report, $fileName);
                $attachment->setIsStringAttachment(true);
                
                $attachments[] = $attachment;
                
                $attOnBody.= "<a href= '".str_replace("PDF", "pdf", $report)."'> Autorização de Fornecimento </a><br/><br/>";
            }
            
            $message = $attOnBody.$message;
        }
        
        $footer = "<div style=\"font-size: 10px; margin-top: 20px; word-wrap: break-word;\"> Email automático enviado pelo Compras. <br/> Disponilizado em: " . DateUtil::getDataAtual() . "</div>";
        
        $bodyMessage = "<table>
                            <tr>
                                <td class='description'>
                                    <br/>" . $message .
                                "</td>
                            </tr>
                            <tr class='footer'>
                                <td>
                                    <br> <p>" . $footer . "</p>
                                </td>
                            </tr>
                        </table>";
        
        return [$bodyMessage, $attachments, $clearAttachments];
    }
    
    public function tratarMensagemCorpoEmail($email, $rows) {
        $message    = "Gestão " . $email['NMOPERADOR'] .",<br>Informamos que o processo de Aprovação/Reprovação da AF: ". $rows[0]['NRAUTOFORN'] ." foi concluído dia " . DateUtil::getDataAtual() . " com o seguinte diagnóstico:<br>";
        
        $aprov = array();
        $repro = array();
        
        foreach($rows as $row) {
            if($row['NMSITITEM'] == 'A') {
                $aprov[] = $row;
            }
            if($row['NMSITITEM'] == 'R') {
                $repro[] = $row;
            }
        }
        
        if(count($aprov) > 0) {
            $message .= "<b>Itens Aprovados: </b><br>";
            
            foreach($aprov as $itm) {
                $message .= $itm['CDARVPROD'] . ' - ' . $itm['NMPRODUTO'] . '<br>';
                
                if($itm['QTNOVAPROGAF'] != null) {
                    $message .= 'Qtde. Original: ' . $itm['QTORIG'] . ' alterada para Qtde.: ' . $itm['QTNOVAPROGAF'] . '<br>';
                }
                if($itm['DTNOVAENTRAF'] != null) {
                    $message .= 'Dt. Entrega Original: ' . substr($itm['DTPROGENTAF'], 0, 10) . ' alterada para Dt.: ' . substr($itm['DTNOVAENTRAF'], 0, 10) . '<br>';
                }
            }
        }
        if(count($repro) > 0) {
            $message .= "<b>Itens Reprovados: </b><br>";
            
            foreach($repro as $itm) {
                $message .= $itm['CDARVPROD'] . ' - ' . $itm['NMPRODUTO'] . '<br>';
                
                if($itm['QTNOVAPROGAF'] != null) {
                    $message .= 'Qtde. Original: ' . $itm['QTORIG'] . ' alterada para Qtde.: ' . $itm['QTNOVAPROGAF'] . ' (Justificativa: ' . $itm['JUSTIFICATIVA'] .')<br>';
                }
                if($itm['DTNOVAENTRAF'] != null) {
                    $message .= 'Dt. Entrega Original: ' . substr($itm['DTPROGENTAF'], 0, 10) . ' alterada para Dt.: ' . substr($itm['DTNOVAENTRAF'], 0, 10) . ' (Justificativa: ' . $itm['JUSTIFICATIVA'] .')<br>';
                }
            }
        }
        
        return $message;
    }
    
    public function enviaEmailDeAprovacao($emails, $rows) {
        try {
            foreach($emails as $email) {
                $enderecos = $email['EMAIL'];
                $assunto = 'Diagnóstico de Aprovação/Reprovação de AF';
                $corpoEmail = $this->cmpUtilities->messageSendMail(null, $assunto, self::tratarMensagemCorpoEmail($email, $rows), 'PORTAL E-COMMERCE');
                
                $this->cmpUtilities->enviaEmail('', $assunto, $enderecos, $corpoEmail, $enderecos, null, false, true);
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function enviaEmailGestor($email, $af) {
        try {
            $attrImg = 'width="200px"';
    	    $srcLogo = $this->cmpUtilities->returnLogo('PORTAL E-COMMERCE');
            $this->cmpUtilities->getLogoAttributes($srcLogo, $attrImg);
            $lgpd = $this->cmpUtilities->returnLgpd($af['CDFILLANC']);
            
            $subject = 'Aviso de Alteração de AF';
            $assunto = "<p class='bold' style='text-align: center; color: #ED2424'>Aviso de Alteração de AF</p>";
            $attOnBody = '';
            
            try {
                $mensagem = "";
                $mensagem .= "<p>" . $email["NMOPERADOR"] . ", </p>";
                $mensagem .= "<p> Abaixo seguem as informações da autorização do fornecimento cuja alteração deve ser analisada por você. São elas: </p>";
                $mensagem .= "<ul>
                    <li><strong>AF: </strong>" . $af["NRAUTOFORN"] . "</li>
                    <li><strong>Unidade Lançamento: </strong>" . $af["CDFILLANC"] . "</li>
                    <li><strong>Unidade Destino: </strong>" . $af["CDFILDEST"] . "</li>
                    <li><strong>Data de Entrega: </strong>" . substr($af["DTPROGENTAF"], 0, 10) . "</li>
                    <li><strong>Comprador: </strong>" . $af["NMOPERADOR"] . "</li>
                    <li><strong>Fornecedor: </strong>" . $af["NMRAZSOCFORN"] . "</li>
                    </ul>";
                    
                foreach ($this->globalReports as $name => $report) {
                    $fileName = $af["NRAUTOFORN"] . '.' . strtolower('PDF');
                        
                    $attachment = new Attachment($report, $fileName);
                    $attachment->setIsStringAttachment(true);
                        
                    $attachments[] = $attachment;
                        
                    $attOnBody.= "<a href= '".str_replace("PDF", "pdf", $report)."'> Autorização de Fornecimento </a><br/><br/>";
                }
                    
                $mensagem = $attOnBody.$mensagem;
                                  
                $messageSendMail = $this->cmpUtilities->returnMessageSendMail($srcLogo, $assunto, $mensagem, $attrImg, $lgpd);
                $this->cmpUtilities->enviaEmail('', $subject, $email['EMAIL'], $messageSendMail, $email['EMAIL'], $email['EMAIL'], $attachments, true);
            } catch(\Exception $e){
                    throw $e;
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
}