<?php
namespace Teknisa\CMP\Modules\Fornecimento\Modules\AutorizacaoFornecimento\Services;

use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Doctrine\ORM\EntityManager;

class CMP03905ImportacaoSolicitacaoComprasService
{
    protected $entityManager;
    protected $connection;
    protected $environment;
    protected $newCode;
    
    public function __construct($entityManager, $environment, $newCode)
    {
        $this->entityManager = $entityManager;
        $this->connection  = $entityManager->getConnection();
        $this->environment = $environment;
        $this->newCode = $newCode;
    }
    
    public function realizaCommit() {
        $this->entityManager->commit();
    }
    
    public function realizaRollback() {
        $this->entityManager->rollBack();
    }
    
    public function beginTransaction() {
        $this->entityManager->beginTransaction();
    }
    
    public function adqUtModProd($params)
    {
        $query = "SELECT IDBLPRCOMEST, NVL(IDUTMODPRODFIL, 'N') IDUTMODPRODFIL
                  FROM PARAMFILIAL
                 WHERE CDFILIAL = :P_CDFILIAL";
                 
        $std = $this->connection->prepare($query);
        $std->execute(
            [
                'P_CDFILIAL' => $params['P_CDFILIAL'],
            ]
        );
        
        return $std->fetchAll();
    }
    
    public function getDataProcessamentoFilial($params)
    {
        $query = "SELECT DTPROCESSA, DTPROCESSA + 1 AS DTPROCESSAFUT FROM (SELECT (
                      CASE PARAMGERAL.IDUTILDTPROC
                        WHEN 'N'
                        THEN SYSDATE
                        ELSE NVL(PARAMFILIAL.DTPROCESSA, SYSDATE)
                      END) DTPROCESSA
                    FROM PARAMGERAL,
                      PARAMFILIAL
                    WHERE PARAMFILIAL.CDFILIAL = :P_CDFILIAL)";
                 
        $std = $this->connection->prepare($query);
        $std->execute(
            [
                'P_CDFILIAL' => $params['P_CDFILIAL'],
            ]
        );
        
        return $std->fetchAll();
    }
    
    public function retornaProdutosFornecedor($params) {
         $query = "SELECT 'U' AS IDCHECK, FILIAL.CDFILIAL CDFILSOLI, ITMAPURPREC.CDCENTITMAP CDFILLAN, NRSEQITMAP NRSOLICMP,  PRODUTO.CDPRODUTO, DTENTRAPUT DTPROGENTR,   QTACOMP QTSOLIPROD, PRODUTO.NMPRODUTO, PRODUTO.CDARVPROD, PRODUTO.SGUNIDADE, CALC_ESTOQ_CONS(FILIAL.CDFILIAL, PRODUTO.CDPRODESTO, SYSDATE) / PRODUTO.VRFATOCONV AS QTESTOQUE, MARCA.CDMARCA, MARCA.NMMARCA , VRPRECUNIAP VRCUSTO, ITMAPURPREC.NRORG
                    FROM ITMAPURPREC, PRODUTO, FILIAL, MARCA
                    WHERE ITMAPURPREC.CDCENTITMAP  = :P_CDFILCENTCMP
                       AND ITMAPURPREC.NRSEQITMAP   = :P_NRAPURPREC
                       AND ITMAPURPREC.CDFILIAP     = FILIAL.CDFILIAL
                       AND ITMAPURPREC.CDPRODITMAP  = PRODUTO.CDPRODUTO
                       AND ITMAPURPREC.CDMARCITMAP  = MARCA.CDMARCA
                       AND ((INSTR(:P_CDFILIAL, FILIAL.CDFILIAL ) > 0) OR (:P_CDFILIAL = 'T'))
                       AND ((PRODUTO.CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN) OR (:P_CDPRODFIN = 'T'))
                       --AND ITMAPURPREC.IDITMSELAPUR = :P_ITEMINCONSISTENTE
                       AND :P_ITEMINCONSISTENTE = :P_ITEMINCONSISTENTE
                       AND NOT EXISTS (SELECT 1
                                         FROM AUTOFORNE, ITEMAUTF I, PRODUTO P
                                        WHERE I.CDFILDEST           = AUTOFORNE.CDFILDEST
                                          AND I.CDFILLANC           = AUTOFORNE.CDFILLANC
                                          AND I.NRAUTOFORN          = AUTOFORNE.NRAUTOFORN
                                          AND I.CDFILDEST           = ITMAPURPREC.CDFILIAP
                                          AND I.DTENTRITMSOL        = ITMAPURPREC.DTENTRAPUT
                                          AND I.CDPRODUTO           = P.CDPRODUTO
                                          AND PRODUTO.CDPRODESTO    = P.CDPRODESTO
                                          AND AUTOFORNE.NRSEQAPURAF = ITMAPURPREC.NRSEQITMAP
                                          AND AUTOFORNE.CDFORNECED  = ITMAPURPREC.CDFORNITMAP)
                     
                     ORDER BY FILIAL.CDFILIAL, CDARVPROD";
                 
        $std = $this->connection->prepare($query);
        $std->execute(
            [
                'P_CDFILCENTCMP' => $params['CDFILCENTCMP'],
                'P_NRAPURPREC' => $params['NRAPURPREC'],
                'P_CDFILIAL' => $params['CDFILIAL'],
                'P_CDPRODINI' => isset($params['CDPRODINI']) ? $params['CDPRODINI'] : null,
                'P_CDPRODFIN' => isset($params['CDPRODFIN']) ? $params['CDPRODINI'] : null,
                'P_ITEMINCONSISTENTE' => isset($params['ITEMINCONSISTENTE']) ? $params['ITEMINCONSISTENTE'] : null,
            ]
        );
        return $std->fetchAll();
    }
    
    public function procedureIMPORT_PRODFORNCOMP($row) {
        $ROWSAFFECT = "";
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'IMPORT_PRODFORNCOMP ');
        $procedure->addParam(new Param('P_CDFILDEST',  Param::PARAM_INPUT,   isset($row["CDFILDEST"]) ? $row["CDFILDEST"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRAPURPREC',  Param::PARAM_INPUT,   isset($row["NRAPURPREC"]) ? $row["NRAPURPREC"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODINI',  Param::PARAM_INPUT,   isset($row["CDPRODINI"]) ? $row["CDPRODINI"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODFIN',  Param::PARAM_INPUT,   isset($row["CDPRODFIN"]) ? $row["CDPRODFIN"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTENTREGA',  Param::PARAM_INPUT,   isset($row["DTENTREGA"]) ? $row["DTENTREGA"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDCOMPRADOR',  Param::PARAM_INPUT,   isset($row["CDCOMPRADOR"]) ? $row["CDCOMPRADOR"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR',  Param::PARAM_INPUT,   isset($row["CDOPERADOR"]) ? $row["CDOPERADOR"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIAL',  Param::PARAM_INPUT,   isset($row["CDFILIAL"]) ? $row["CDFILIAL"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFORNECED',  Param::PARAM_INPUT,   isset($row["CDFORNECED"]) ? $row["CDFORNECED"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDCUSTO',  Param::PARAM_INPUT,   isset($row["CDTIPOCUSTO"]) ? $row["CDTIPOCUSTO"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_LISTAPRECO',  Param::PARAM_INPUT,   isset($row["CARREGARPRECOLISTA"]) ? $row["CARREGARPRECOLISTA"] : null,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ROWSAFFECT',      Param::PARAM_OUTPUT,  $ROWSAFFECT,           Param::PARAM_TYPE_STR));
        $ROWSAFFECT = $procedure->execute();
        return $ROWSAFFECT;
    }
    
    public function generateCode($newCode) {
        $organizacao = $this->environment->getNrOrgTrab();
        $nrLanctoNfNota = $this->newCode->getCodeByTableName($newCode, $organizacao);
        return $nrLanctoNfNota;
    }
}
