<?php
namespace Teknisa\CMP\Modules\NecessidadeCompras\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\GER\Utilities\Environment;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Setforms2\Shared\ORM\DateTime;
use Zeedhi\Framework\DataSource\DataSet;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Teknisa\CMP\Util\CmpUtilities;
use Teknisa\CMP\Modules\NecessidadeCompras\Services\CalculoNecessidadeComprasService;

class CalculoNecessidadeCompras
{

    protected $environment;
	protected $dataSourceManager;
	protected $entityManager;
	protected $connection;
	protected $newCode;
	protected $smtpUtil;
    protected $cmpUtilities;
	
    const MENSAGEM_EXTRA = "Cálculo da Necessidade de Compras-Extra";
    const NOME_LISTA_OPERADOR = "LISTA_OPERADOR_CALCULO_SEGUNDO_PLANO";
    const TITULO_EMAIL = "Cálculo da Necessidade de Compras";
        
    public function __construct(Environment $environment, $dataSourceManager, $entityManager, $connection, $newCode, $smtpUtil, CmpUtilities $cmpUtilities, CalculoNecessidadeComprasService $service)
    {
		$this->environment = $environment;
		$this->dataSourceManager = $dataSourceManager;
		$this->entityManager = $entityManager;
        $this->connection = $connection;
        $this->newCode = $newCode;
        $this->smtpUtil = $smtpUtil;
        $this->cmpUtilities = $cmpUtilities;
        $this->service = $service;
	}
	
    public function defineCookie($name, $value = "", $time = 0, $path = "/", $domain = "", $secure = false, $httponly = false)
    {
        setcookie($name, $value, $time, $path, $domain, $secure, $httponly);
    }
    
    public function retornaCookie(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $mensagem = false;
        
        if(\Zeedhi\Framework\Util\Functions::arrayKeyExists($row['NOME_COOKIE'], $_COOKIE)){
            $mensagem = $_COOKIE[$row['NOME_COOKIE']];
        }

        $response->addMessage(new Message($mensagem));
    }
     
    public function setEstoque(DTO\Request\Row $request, DTO\Response $response) 
    {
        try {
            $row = $request->getRow();
            $resposta = $this->service->selectEstoque($row);
            $response->addDataSet(new DataSet("resposta", $resposta));
        } catch (\Exception $e){
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function setDados(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            $central = $this->service->selectCentral();
            $resposta['CENTRALCMP'] = $central;
            
            $resposta['CDGRUPPROD'] = $this->service->selectGrupo($central);
            
            $calen = $this->service->selectCardapio();
            $resposta['IDSISDOS'] = $calen['IDSISDOS'];
            $resposta['IDUTCARDPADR'] = $calen['IDUTCARDPADR'];
            
            $dados = $this->service->selectDados();
            $resposta['IDCALPREVCON'] = $dados['IDCALPREVCON'];
            $resposta['IDPERACRNEC'] = $dados['IDPERACRNEC'];
            $resposta['IDSCONESTNEC'] = $dados['IDSCONESTNEC'];
    
            $response->addDataSet(new DataSet("resposta", $resposta));   
        } catch (\Exception $e){
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function previsoes(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            
            $dataFinal = $this->service->calculaDataLimiteSeguranca($row['CDFILIAL'], $row['CDPRODINI'], $row['PRODUTOFIN'], $row['GROUPFILI'], $row['DTFIM']);
    
            $inicioDataInicial = '01' . substr($row['DTINI'], 2, 9);
            $inicioDataFinal = '01' . $dataFinal->format('/m/Y');
            
            $resposta = $this->service->selectGetServNAprov($inicioDataInicial, $inicioDataFinal, $row['CDFILIAL'], $row['GROUPFILI']);
    
            $response->addDataSet(new DataSet("resposta", $resposta));
        } catch (\Exception $e){
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function existeSolicitacao(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        try {
            if (empty($row['SUBGRUPO'])) {
                $resposta = $this->service->existeSolicitacaoMerenda($row);
            } else {
                $subgrupo = $row['SUBGRUPO'] ? $row['SUBGRUPO'] : 'T';
                $resposta = $this->service->selectVerifica_Sol($row['DTINI'], $row['DTFIM'], $row['CDFILIAL'], $row['GROUPFILI'], $row['CDPRODINI'], $row['PRODUTOFIN'], $subgrupo, $row['CDGRUPPROD']);
            }
            $response->addDataSet(new DataSet("resposta", $resposta));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function dataLimiteSeguranca(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        
        $data = $this->service->calculaDataLimiteSeguranca($row['CDFILIAL'], $row['CDPRODINI'], $row['PRODUTOFIN'], $row['GROUPFILI'], $row['DTFIM']);
        $resposta['DATSEGU'] = $data->format('d/m/Y');

        $response->addDataSet(new DataSet("resposta", $resposta));
    }
    
    public function GetPrxConsPlan(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $servico = $this->service->adqParamServico($row['CDFILIAL'], $row['GROUPFILI']);
            
            if(((is_array($servico) && !is_null($servico)) ? count($servico) : 0) != 0){
                $resposta['MSG'] = $row['MSGBACK'];
                $response->addDataSet(new DataSet("resposta", $resposta));    
            } else {
                $this->service->CALCULA_PREVCONS_FILIAIS($row['CDFILIAL'],  $row['TCDFILIAL'], $row['GROUPFILI'], $row['DATFIMSEGU'], $row['PEACRESCIMO'], $row['CDPRODINI'], $row['CDPRODFIN']);
                $resposta['MSG'] = null;
                $response->addDataSet(new DataSet("resposta", $resposta));    
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function PrxNeceBkg(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        
        $resposta['NRNECECOMP'] = $this->newCode->getCodeByTableName('NECECOMP', $this->environment->getNrorg());

        try {
            $filialBkp = $this->service->adqFilialBkg($row['CDFILIAL'], $row['GROUPFILI']);
            $resposta['UNIDADE'] = $filialBkp;
            $response->addDataSet(new DataSet("resposta", $resposta));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function GetPrxNeceComp(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $date = new DateTime();
        $date = $date->format('d/m/Y H:i:s');
       
        try {
            if($row['CALENDARIO'] == 'S') {
                $this->service->PERIODICIDADE_NAO_CALCULADA($row['CDFILIAL'], $row["TCDFILIAL"], $row['GROUPFILI'], $row['CDPRODINI'], $row['CDPRODFIN']);
            }
            
            $this->service->NECESSIDADE_DE_COMPRAS($row['CDFILIAL'], $row["TCDFILIAL"], $row['GROUPFILI'], $row['DTINI'], $row['DTFIM'], $row['CDPRODINI'], $row['CDPRODFIN'], $date, $row['PEACRESCIMO'], $row['NECECOMP'], $row['EXTRA'], $row['SUBGRUPO'], $row['CDGRUPPROD']);
            $this->service->acmUpdLogNeceComp($row['CDFILIAL'], $row['GROUPFILI'], $date, $row['IDCALPREVCON'], $row['NECECOMP'], $row['SUBGRUPO']);
            
            $confereNeceComp = $this->service->adqConfereNeceComp($row['NECECOMP'], $row['DTINI']);
               
            if(((is_array($confereNeceComp) && !is_null($confereNeceComp)) ? count($confereNeceComp) : 0) == 0) {
                $resposta['NECECOMP'] = 'N';
            } else {
                $resposta['NECECOMP'] = $confereNeceComp;
            }
            
            $produtoinativo = $this->service->adqProdInativo($row['NECECOMP']);
            $resposta['PRODUTO_INATIVO'] = $produtoinativo;
            $response->addDataSet(new DataSet("resposta", $resposta));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function calcNeceCompSegundoPlano(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        self::defineCookie(self::NOME_LISTA_OPERADOR, $row['LISTAOPERADOR']);
        
        $file = __DIR__.DIRECTORY_SEPARATOR.'CalculoNecessidadeComprasSegundoPlano.php';

        $requestUri = $_SERVER["REQUEST_URI"];

        if(strpos($requestUri, "modules") == false) {
            $urlCalcSegPlano = $_SERVER["HTTP_HOST"].'/backend_cmp/index.php/geraSolicitacaoComprasSegundoPlano';
        } else {
            if(strpos($_SERVER["DOCUMENT_ROOT"], "workfolder") != false) {
                $urlCalcSegPlano = $_SERVER["HTTP_HOST"].'/workfolder'.$_SERVER["REQUEST_URI"];
            } else {
                $urlCalcSegPlano = $_SERVER["HTTP_HOST"].$_SERVER["REQUEST_URI"];
            }
        }
        $urlCalcSegPlano = 'http://' . str_replace("calcNeceCompSegundoPlano", "geraSolicitacaoComprasSegundoPlano", $urlCalcSegPlano);
        
        $parameters = array("requestType" => "Row", "row" => $row);

        $parameters = base64_encode(json_encode($parameters));
        
        $tokenLogin = $this->environment->getLoginTokenInSession();
        
        exec("php $file $urlCalcSegPlano $parameters $tokenLogin > /tmp/logCalcNeceCompSegundoPlano.txt &");
    }
    
    public function geraSolicitacaoComprasSegundoPlano(DTO\Request\Row $request) {
        $row = $request->getRow();
        
        $date = new DateTime();
        $date = $date->format('d/m/Y H:i:s');
        
        try {
            $listaEmails = $this->service->retornaListaEmailOperador($row['LISTAOPERADOR']);
            
            if($row['CALENDARIO'] == 'S') {
                $this->service->PERIODICIDADE_NAO_CALCULADA($row['CDFILIAL'], $row['TCDFILIAL'], $row['GROUPFILI'], $row['CDPRODINI'], $row['CDPRODFIN']);
            }
            
            $this->service->NECESSIDADE_DE_COMPRAS($row['CDFILIAL'], $row['TCDFILIAL'], $row['GROUPFILI'], $row['DTINI'], $row['DTFIM'], $row['CDPRODINI'], $row['CDPRODFIN'], $date, $row['PEACRESCIMO'], $row['NECECOMP'], $row['EXTRA'], $row['SUBGRUPO'], $row['CDGRUPPROD']);
            
            $this->service->acmUpdLogNeceComp($row['CDFILIAL'], $row['GROUPFILI'], $date, $row['IDCALPREVCON'], $row['NECECOMP'], $row['SUBGRUPO']);
            
            $confereNeceComp = $this->service->adqConfereNeceComp($row['NECECOMP'], $row['DTINI']);
            
            if(((is_array($confereNeceComp) && !is_null($confereNeceComp)) ? count($confereNeceComp) : 0) > 0) {
                $this->service->GERA_SOLICITACAO($row['NECECOMP'], $row['EXTRA'], self::MENSAGEM_EXTRA);
            } else {
                throw new \Exception("Cálculo da necessidade de compras não apurou informações.");
            }
        
            
            $horaFinal = new DateTime();
            $horaFinal = $horaFinal->format('d/m/Y H:i:s');
            
            self::enviaEmail($listaEmails, $row['EMAILLOGADO'], self::TITULO_EMAIL, $row['NECECOMP'], 'sucesso', $date, $horaFinal);
        } catch(\Exception $e) {
            $erro = $e->getMessage();
            
            $horaFinal = new DateTime();
            $horaFinal = $horaFinal->format('d/m/Y H:i:s');
            
            self::enviaEmail($listaEmails, $row['EMAILLOGADO'], self::TITULO_EMAIL, $row['NECECOMP'], 'erro', $date, $horaFinal, $erro);
        }
        
    }
    
    public function enviaEmail($listaEmails, $emailLogado, $assunto, $previa, $status, $horaInicio, $horaFinal, $erro = null)
    {
        $message = "<table>
                        <tr>
                            <td class='title'> 
                                <div>
                                    <br/>" . $assunto . "
                                </div>
                            </td>
                        </tr>
                        <tr>
                            <td class='description'>
                                <div>
                                    <p> Prezado(a), <br><br> O processo de 'Cálculo da Necessidade de Compras' em segundo plano para a prévia de n° ". $previa ." foi concluído com <b>". $status ."</b>. <br><br> Início: ". $horaInicio ." <br> Final: ". $horaFinal ."<br><br><b>". $erro ."</b></div>
                            </td>
                        </tr>
                        <tr class='footer'>
                            <td>
                                <center>
                                    <br> <p> Email automático enviado pelo Compras. </p> 
                                </center>
                            </td>
                        </tr>
                    </table>";
        $cdFilial = $this->environment->getCdfilial();

        $messageSendMail = $this->cmpUtilities->messageSendMail($cdFilial, $assunto, $message, 'PORTAL E-COMMERCE');
        $this->cmpUtilities->enviaEmail($emailLogado, $assunto, $listaEmails, $messageSendMail, $listaEmails);
        
        $messageSendMail = $this->cmpUtilities->messageSendMail($cdFilial, $assunto, $message, 'PORTAL E-COMMERCE');
        $this->cmpUtilities->enviaEmail($emailLogado, $assunto, $listaEmails, $messageSendMail, $listaEmails);
    }
    
    public function GetPrxNeceCompMerenda(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $date = new DateTime();
        $date = $date->format('d/m/Y H:i:s');
       
        try {
            $row['NECECOMP'] = $this->newCode->getCodeByTableName('NECECOMP', $this->environment->getNrorg());
            $this->service->NECESSIDADE_DE_COMPRAS($row['CDFILIAL'], $row['TCDFILIAL'], '', $row['DTINI'], $row['DTFIM'], $row['CDPRODINI'], $row['CDPRODFIN'], $date, $row['PEACRESCIMO'], $row['NECECOMP'], 'N', '', '');
            
            $confereNeceComp = $this->service->adqConfereNeceComp($row['NECECOMP'], $row['DTINI']);
        
            if(((is_array($confereNeceComp) && !is_null($confereNeceComp)) ? count($confereNeceComp) : 0) == 0){    
                $resposta['NECECOMP'] = 'N';
            } else{
                $resposta['NECECOMP'] = $confereNeceComp;
            }    
            
            $produtoinativo = $this->service->adqProdInativo($row['NECECOMP']);
            $resposta['PRODUTO_INATIVO'] = $produtoinativo;
            $response->addDataSet(new DataSet("resposta", $resposta));
            
        } catch (\Exception $e){
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function GetPrxSoliMerenda(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();

        try {
            $this->service->beginTransaction();
            
            $this->service->GERA_SOLICITACAO($row['NECECOMP'], '', '');
            $solicita = $this->service->selectSolicita($row['NECECOMP']);
            
            $response->addNotification(new DTO\Response\Notification("NRSOLICMP", $solicita));
            
            $this->service->commit();
        } catch(\Exception $e){
            $this->service->rollback();
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getDataProcessamentoFilial(DTO\Request\Row $request, DTO\Response $response) {
        $res = $this->service->getDataProcessamentoFilial();
        
        $response->addDataSet(new DataSet('res', $res));
    }
}