<?php

namespace Teknisa\CMP\Modules\V1\Services;

use Doctrine\ORM\EntityManager;

class SolicitacaoComprasSave
{
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function hasItemSoli(Array $row)
    {
        $sql = "SELECT ITEMSOLI.*
                FROM ITEMSOLI
                JOIN SOLICITA
                ON ITEMSOLI.NRSOLICMP = SOLICITA.NRSOLICMP
                AND ITEMSOLI.CDFILLAN = SOLICITA.CDFILLANCA
                AND ITEMSOLI.CDFILSOLI = SOLICITA.CDFILSOLI
                AND ITEMSOLI.NRORG = SOLICITA.NRORG
                WHERE ITEMSOLI.CDPRODUTO = :CDPRODUTO
                AND ITEMSOLI.CDFILLAN    = :CDFILLAN
                AND ITEMSOLI.CDFILSOLI   = :CDFILSOLI
                AND ITEMSOLI.DTPROGENTR  = :DTPROGENTR
                AND ITEMSOLI.NRORG       = :NRORG
                AND SOLICITA.IDSOLEXTRA = :IDSOLEXTRA
                AND SOLICITA.IDTIPLAN = :IDTIPLAN ";
        $params = array(
            "CDPRODUTO" => $row['CDPRODUTO'],
            "CDFILLAN" => $row['CDFILLAN'],
            "CDFILSOLI" => $row['CDFILSOLI'],
            "DTPROGENTR" => $row['DTPROGENTR'],
            "NRORG" => $row['NRORG'],
            "IDSOLEXTRA" => $row['IDSOLEXTRA'],
            "IDTIPLAN" => $row['IDTIPLAN']
        );
        if ($row['CDDESTSOLI'] == null) {
            $sql.="AND SOLICITA.CDDESTSOLI IS NULL ";
        }
        else {
            $sql.="AND SOLICITA.CDDESTSOLI = :CDDESTSOLI ";
            $params['CDDESTSOLI'] = $row['CDDESTSOLI'];
        }
        if ($row['CDCOMPRADOR'] == null) {
            $sql.="AND SOLICITA.CDOPERADOR IS NULL ";
        }
        else {
            $sql.="AND SOLICITA.CDOPERADOR = :CDCOMPRADOR ";
            $params['CDCOMPRADOR'] = $row['CDCOMPRADOR'];
        }

        $bdRow = $this->entityManager->getConnection()->fetchAll($sql, $params);
        return $bdRow;
    }
    public function insertItemSoli (Array $row) {
        $sql = "INSERT
                INTO ITEMSOLI
                  (
                    CDFILLAN,
                    CDFILSOLI,
                    NRSOLICMP,
                    IDITMSOLEXTRA,
                    CDPRODUTO,
                    DTPROGENTR,
                    DTUTILIZA,
                    QTSOLIPROD,
                    CDOPERINCLUSAO,
                    NRORG
                  )
                  VALUES
                  (
                    :CDFILLAN,
                    :CDFILSOLI,
                    :NRSOLICMP,
                    :IDSOLEXTRA,
                    :CDPRODUTO,
                    :DTPROGENTR,
                    :DTUTILIZA,
                    :QTSOLIPROD,
                    :CDOPERADOR,
                    :NRORG
                  )";
        $params = array(

            "CDFILLAN" => $row['CDFILLAN'],
            "CDFILSOLI" => $row['CDFILSOLI'],
            "NRSOLICMP" => $row['NRSOLICMP'],
            "IDSOLEXTRA" => $row['IDSOLEXTRA'],
            "CDPRODUTO" => $row['CDPRODUTO'],
            "DTPROGENTR" => $row['DTPROGENTR'],
            "DTUTILIZA" => $row['DTUTILIZA'],
            "QTSOLIPROD" => $row['QTSOLIPROD'],
            "CDOPERADOR" => $row['CDOPERADOR'],
            "NRORG" => $row['NRORG']
        );
        $this->entityManager->getConnection()->executeQuery($sql, $params);
    }
    public function updateItemSoli(Array $row)
    {
        $sql = "UPDATE ITEMSOLI SET QTSOLIPROD = :QTSOLIPROD,
                CDOPERULTATU = :CDOPERULTATU,
                NRORGULTATU = :NRORG,
                DTULTATU = :DTULTATU
                WHERE ITEMSOLI.CDPRODUTO = :CDPRODUTO
                AND ITEMSOLI.CDFILLAN    = :CDFILLAN
                AND ITEMSOLI.CDFILSOLI   = :CDFILSOLI
                AND ITEMSOLI.NRSOLICMP   = :NRSOLICMP
                AND ITEMSOLI.DTPROGENTR  = :DTPROGENTR
                AND ITEMSOLI.NRORG       = :NRORG";
        $params = array(
            "CDPRODUTO" => $row['CDPRODUTO'],
            "CDFILLAN" => $row['CDFILLAN'],
            "CDFILSOLI" => $row['CDFILSOLI'],
            "DTPROGENTR" => $row['DTPROGENTR'],
            "NRORG" => $row['NRORG'],
            "NRSOLICMP" => $row['NRSOLICMP'],
            "QTSOLIPROD" => $row['QTSOLIPROD'],
            "CDOPERULTATU" => $row['CDOPERADOR'],
            "DTULTATU" => $row['DTATU']
        );
        $this->entityManager->getConnection()->executeUpdate($sql, $params);
    }
    public function deleteItemSoli (Array $row) {
        $sql = "DELETE FROM ITEMSOLI
                WHERE ITEMSOLI.CDPRODUTO = :CDPRODUTO
                AND ITEMSOLI.CDFILLAN    = :CDFILLAN
                AND ITEMSOLI.CDFILSOLI   = :CDFILSOLI
                AND ITEMSOLI.NRSOLICMP   = :NRSOLICMP
                AND ITEMSOLI.DTPROGENTR  = :DTPROGENTR
                AND ITEMSOLI.NRORG       = :NRORG ";
        $params = array(
            "CDPRODUTO" => $row['CDPRODUTO'],
            "CDFILLAN" => $row['CDFILLAN'],
            "CDFILSOLI" => $row['CDFILSOLI'],
            "DTPROGENTR" => $row['DTPROGENTR_old'],
            "NRORG" => $row['NRORG'],
            "NRSOLICMP" => $row['NRSOLICMP']
        );
        $this->entityManager->getConnection()->executeQuery($sql, $params);
    }
    public function hasSolicita (Array $row) {
        $sql = "SELECT *
                FROM SOLICITA
                WHERE CDFILSOLI = :CDFILSOLI
                AND CDFILLANCA  = :CDFILLAN
                AND DTSOLCMP    = :DTSOLCMP
                AND IDTIPLAN    = :IDTIPLAN
                AND IDSOLEXTRA  = :IDSOLEXTRA
                AND NRORG       = :NRORG ";
        $params = array(
            "CDFILSOLI" => $row['CDFILSOLI'],
            "CDFILLAN" => $row['CDFILLAN'],
            "DTSOLCMP" => $row['DTSOLCMP'],
            "NRORG" => $row['NRORG'],
            "IDSOLEXTRA" => $row['IDSOLEXTRA'],
            "IDTIPLAN" => $row['IDTIPLAN']
        );
        if ($row['CDDESTSOLI'] == null) {
            $sql.="AND CDDESTSOLI IS NULL ";
        }
        else {
            $sql.="AND CDDESTSOLI = :CDDESTSOLI ";
            $params['CDDESTSOLI'] = $row['CDDESTSOLI'];
        }
        if ($row['CDCOMPRADOR'] == null) {
            $sql.="AND CDOPERADOR IS NULL ";
        }
        else {
            $sql.="AND CDOPERADOR = :CDCOMPRADOR ";
            $params['CDCOMPRADOR'] = $row['CDCOMPRADOR'];
        }
        $bdRow = $this->entityManager->getConnection()->fetchAll($sql, $params);
        return $bdRow;
    }
    public function insertSolicita (Array $row) {
        $sql = "INSERT
                INTO SOLICITA
                  (
                    NRSOLICMP,
                    CDFILLANCA,
                    CDFILSOLI,
                    DTSOLCMP,
                    IDTIPLAN,
                    IDSOLEXTRA,
                    CDOPERINCLUSAO,
                    NRORG,
                    CDOPERLANC,
                    CDDESTSOLI,
                    CDOPERADOR
                  )
                  VALUES
                  (
                    :NRSOLICMP,
                    :CDFILLAN,
                    :CDFILSOLI,
                    :DTSOLCMP,
                    :IDTIPLAN,
                    :IDSOLEXTRA,
                    :CDOPERADOR,
                    :NRORG,
                    :CDOPERLANC,
                  ";
        $params = array(
            "NRSOLICMP" => $row['NRSOLICMP'],
            "CDFILLAN" => $row['CDFILLAN'],
            "CDFILSOLI" => $row['CDFILSOLI'],
            "DTSOLCMP" => $row['DTSOLCMP'],
            "IDTIPLAN" => $row['IDTIPLAN'],
            "IDSOLEXTRA" => $row['IDSOLEXTRA'],
            "CDOPERADOR" => $row['CDOPERADOR'],
            "NRORG" => $row['NRORG'],
            "CDOPERLANC" => $row['CDOPERLANC']
        );
        if ($row['CDDESTSOLI'] == null) {
            $sql.="NULL,";
        }
        else {
            $sql.=":CDDESTSOLI,";
            $params['CDDESTSOLI'] = $row['CDDESTSOLI'];
        }
        if ($row['CDCOMPRADOR'] == null) {
            $sql.="NULL";
        }
        else {
            $sql.=":CDCOMPRADOR";
            $params['CDCOMPRADOR'] = $row['CDCOMPRADOR'];
        }
        $sql.=")";
        $this->entityManager->getConnection()->executeQuery($sql, $params);
    }
    public function insertMovoPsol (Array $row) {
        $sql = "INSERT
                INTO MOVOPSOL
                  (
                    CDPRODUTO,
                    NRSOLIMOV,
                    CDFILLANMOV,
                    CDFILSOLMOV,
                    DTENTROPER,
                    DSJUSTOPER,
                    NRORG,
                    CDOPERINCLUSAO,
                    DTOPERSOL
                  )
                  VALUES
                  (
                    :CDPRODUTO,
                    :NRSOLICMP,
                    :CDFILLAN,
                    :CDFILSOLI,
                    :DTPROGENTR,
                    :DSJUSTOPER,
                    :NRORG,
                    :CDOPERADOR,
                    SYSDATE
                  )";
        $params = array(
            "CDPRODUTO" => $row['CDPRODUTO'],
            "NRSOLICMP" => $row['NRSOLICMP'],
            "CDFILLAN" => $row['CDFILLAN'],
            "CDFILSOLI" => $row['CDFILSOLI'],
            "DTPROGENTR" => $row['DTPROGENTR'],
            "DSJUSTOPER" => $row['DSJUSTOPER'],
            "NRORG" => $row['NRORG'],
            "CDOPERADOR" => $row['CDOPERADOR']
        );
        $this->entityManager->getConnection()->executeQuery($sql, $params);
    }
} 