<?php

require_once 'base/GepApropriacaoEntityBase.php';

/**
 * GepTipoItemtrabalhoEntity.
 *
 * @package Entity
 *
 * @author  robertomartins
 */
class GepApropriacaoEntity extends GepApropriacaoEntityBase
{


    /**
     * Retorna dados da apropriacao pela atividade.
     *
     * @param integer $nrorg       Numero da Organizacao.
     * @param integer $nratividade Numero da Atividade.
     *
     * @return Ambigous <<type>, multitype:, mixed>|boolean
     */
    public static function consultaDadosApropriacaoByAtividade($nrorg, $nratividade){
        $dados = GepApropriacao::consultaDadosApropriacaoByAtividade($nrorg, $nratividade);

        if ($dados instanceof GepApropriacaoEntity)
            return $dados;

        return false;
    }


    /**
     * Retorna o inicio da data de apropriacao.
     *
     * @param string $nratividade Numero da Atividade.
     * @param string $nrorg       Numero da Organizacao.
     *
     * @return Ambigous <boolean, mixed, NULL>
     */
    public static function retornaDataDeInicioApropriacao($nratividade, $nrorg){
        $consulta = GepApropriacao::consultaDataDeInicioApropriacao($nratividade, $nrorg);
        return $consulta[0]['DTINICIADO'];
    }


    /**
     * Altera Apropriacao.
     *
     * @param integer $nrparcoperresp      Numero do Parceiro.
     * @param integer $nratividade         Numero da atividade.
     * @param date    $dtinicioapropriacao Data de inicio da apropriacao.
     * @param date    $dtfimapropriacao    Data fim da apropriacao.
     * @param date    $dtultatu            Data de atualizacao.
     * @param string  $nrorgultatu         Numero da organizacao do operador que atualizou.
     * @param string  $cdoperadorultatu    Codigo do operador que realizou a atualizacao.
     * @param integer $nrorg               Numero da organizacao.
     *
     * @return boolean
     */
    public static function alteraApropriacao(
        $nrparcoperresp, $nratividade, date $dtinicioapropriacao,
        date $dtfimapropriacao, date $dtultatu, $nrorgultatu,
        $cdoperadorultatu, $nrorg
    ){
        $lista_apropriacao = GepApropriacao::getObjectsByWhere(
            ' NRPARCOPERRESP = ? AND NRATIVIDADE = ? AND NRORG = ?',
            array(
             $nrparcoperresp, $nratividade, $nrorg,
            )
        );
        foreach ($lista_apropriacao as $apr) {
            $apr->setDtinicioapropriacao($dtinicioapropriacao);
            $apr->setDtfimapropriacao($dtfimapropriacao);
            $apr->setDtultatu($dtultatu);
            $apr->setNrorgultatu($nrorgultatu);
            $apr->setCdoperultatu($cdoperadorultatu);
            $apr->setNrorg($nrorg);
            $apr->persist();
        }

        return true;

    }


    /**
     * Atualiza data da apropriacao.
     *
     * @param integer $nrparcoperresp          Numero do parceiro responsavel.
     * @param integer $nratividade             Numero da atividade.
     * @param string  $dtiniciorealapropriacao Data de inicio real da apropriacao.
     * @param string  $dtfimrealapropriacao    Data de fim real da apropriacao.
     * @param string  $dtultatu                Data da ultima atualizacao.
     * @param integer $nrorgultatu             Numero da organizacao na atualizacao.
     * @param integer $cdoperadorultatu        Codigo do operador na atualizacao.
     * @param integer $nrorg                   Numero da organizacao.
     *
     * @return boolean
     */
    public static function atualizaDtRealApropriacao(
        $nrparcoperresp, $nratividade, $dtiniciorealapropriacao,
        $dtfimrealapropriacao, $dtultatu, $nrorgultatu,
        $cdoperadorultatu, $nrorg
    ){
        $lista_apropriacao = GepApropriacao::getObjectsByWhere(
            ' NRPARCOPERRESP = ? AND NRATIVIDADE = ? AND NRORG = ?',
            array(
             $nrparcoperresp, $nratividade, $nrorg,
            )
        );
        foreach ($lista_apropriacao as $apr) {
            $apr->setDtinicioaproprireal($dtiniciorealapropriacao);
            $apr->setDtfimaproprireal($dtfimrealapropriacao);
            $apr->setDtultatu($dtultatu);
            $apr->setNrorgultatu($nrorgultatu);
            $apr->setCdoperultatu($cdoperadorultatu);
            $apr->setNrorg($nrorg);
            $apr->persist();
        }

        return true;

    }


     /**
      * Insere na tabela Apropriacao.
      *
      * @param integer $nratividade         Numero da atividade.
      * @param string  $dtinicioapropriacao Data de inicio da apropriacao.
      * @param string  $dtfimapropriacao    Data de fim de apropriacao.
      * @param string  $dtinicioaproprireal Data de inicio da apropriacao real.
      * @param string  $dtfimaproprireal    Data de fim de apropriacao real.
      *
      * @return void
     */
    public static function insereApropriacao(
         $nratividade,
         $dtinicioapropriacao,
         $dtfimapropriacao,
         $dtinicioaproprireal,
         $dtfimaproprireal
    ){
        try {
            $now = now();
            $nrorg = Ambiente::getNrorg();
            $cdoperador = Ambiente::getCdOperador();
            $nrparceiro = Ambiente::getParceiroNegocio();
            $nrapropriacao = Novocodigo::geraCodigo('1', 'APROPRIACAO', 10);
            $idativo = 'S';
            $txapropriacao = "";
            $obj = new self();
            $obj->setNrapropriacao($nrapropriacao);
            $obj->setNratividade($nratividade);
            $obj->setNrparcoperresp($nrparceiro);
            $obj->setDtinicioapropriacao($dtinicioapropriacao);
            $obj->setDtfimapropriacao($dtfimapropriacao);
            $obj->setDtinicioaproprireal($dtinicioaproprireal);
            $obj->setDtfimaproprireal($dtfimaproprireal);
            $obj->setTxapropriacao($txapropriacao);
            $obj->setNrorg($nrorg);
            $obj->setIdativo($idativo);
            $obj->setDtinclusao($now);
            $obj->setDtultatu($now);
            $obj->setNrorginclusao($nrorg);
            $obj->setNrparcoperresp($nrparceiro);
            $obj->setCdoperinclusao($cdoperador);
            $obj->setNrorgultatu($nrorg);
            $obj->setCdoperultatu($cdoperador);
            $obj->persist();
        } catch(Exception $e) {
            showClassError($e, __FUNCTION__, __LINE__);
       }
    }


    /**
     * Exclui Apropriacao por atividade.
     *
     * @param integer $nrorg       Numero da Organizacao.
     * @param integer $nratividade Numero da Atividade.
     *
     * @return Ambigous <number, number>
     */
    public static function excluiApropriacaoByAtividade($nrorg, $nratividade){
        $dado =  GepApropriacao::excluiApropriacaoByAtividade($nrorg, $nratividade);
        return $dado;
    }


    /**
     * Consulta datas de apropriacao.
     *
     * @param string $nrparcoperresp  Numero do operador responsavel.
     * @param string $dtinicioreuniao Data de inicio da reuniao.
     * @param string $nrorg           Numero da organizacao.
     *
     * @return Ambigous <mixed, NULL>|boolean
     */
    public static function consultaDataApropriacao(
        $nrparcoperresp, $dtinicioreuniao, $nrorg
    ){
        $consulta = GepApropriacao::consultaMaiorDataApropriacao($nrparcoperresp, $dtinicioreuniao, $nrorg);
        $apropriacao = GepApropriacao:: consultaDadosApropriacaoByParceiroEData(
            $nrparcoperresp,
            $consulta[0]['MAX'],
            $nrorg
        );

        return $apropriacao;
    }


    /**
     * Consulta apropriacao de um determinado periodo.
     *
     * @param integer $nrparcoperresp Nmero do Operador.
     * @param string  $dataIni        Data de Inicio.
     * @param string  $dataFim        Data de Fim.
     * @param integer $nrorg          Nmero da Organizao.
     *
     * @return Ambigous <<type>, multitype:, mixed>|boolean
     */
    public static function consultaDadosApropriacaoByPeriodoDeDatas($nrparcoperresp, $dataIni, $dataFim, $nrorg){
        $existeApr = GepApropriacao::consultaDadosApropriacaoByPeriodoDeDatas($nrparcoperresp, $dataIni, $dataFim, $nrorg);
        if (count($existeApr) > 0) {
            return $existeApr[0];
        }

        return false;
    }


    /**   ok
     * Retorna o proximo codigo novo da apropriacao.
     *
     * @param integer $nrorg Numero da Organizacao.
     *
     * @return integer
     */
    public static function geraNovoCodigoApropriacao($nrorg) {
        $codigo = Novocodigo::geraCodigo($nrorg, 'GEP_APROPRIACAO', 10);
        return $codigo;
    }
}